function [q1,q2,r,v,q3,q4] = OrbitPlane( a,e,mu,True )
% [q1,q2,r,v,q3,q4] = OrbitPlane(a,e,mu,True)
%
% a   semi major axis in meter
% e   eccentricity
% mu  gravitational constant
% q1  in-plane coordinate pointing to perigee
% q2  in-plane coordinate perpendicular to perigee
% r   radius of the satellite
% v   velocity of the satellite
% q3  in-plane velocity pointing to the perigee
% q4  in-plane velocity perpendicular to the perigee
p = a*(1-e*e);
ct = cos(True);
st = sin(True);
r = p ./ (1 + e*ct);
v = sqrt(mu*(2./r-1/a));
q1 = r .* ct;
q2 = r .* st;
hulp0 = sqrt(mu/p);
hulp1 = hulp0 .* e * st;
hulp2 = hulp0 .* (1 + e * ct);
q3 = hulp1 .* ct - hulp2 .* st;
q4 = hulp1 .* st + hulp2 .* ct;
